%% aaateBoEA.cls
%% Style for AAATE 2023 Conference Book of Extended Abstracts
%%
%% Modified from the `Stylish Article' (SelfArx.cls),  see information below
%% by Dominique Archambault
%% licence of the current document is the same as the original one
%% namely CC BY-NC-SA 3.0
%%
%% Original information
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Stylish Article
% Class File
% Version 2.2 (2020-10-22)
%
% This template has been downloaded from:
% https://www.latextemplates.com/template/stylish-article
%
% Original author:
% Mathias Legrand (legrand.mathias@gmail.com)
% With extensive modifications by:
% Vel (vel@latextemplates.com)
%
% License:
% CC BY-NC-SA 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%----------------------------------------------------------------------------------------
%	CLASS CONFIGURATION
%----------------------------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{aaateBoEA}[21/04/2023, v1.0]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}} % Pass through any options to the base class
\ProcessOptions\relax % Process given options

\LoadClass[fleqn,10pt,twoside]{article} % Load the base class

%----------------------------------------------------------------------------------------
%	REQUIRED PACKAGES AND DOCUMENT CONFIGURATIONS
%----------------------------------------------------------------------------------------

\RequirePackage{ifthen}
\RequirePackage{calc}
\RequirePackage{amsmath, amsfonts, amssymb}
\RequirePackage{graphicx}
\graphicspath{{Figures/}{./}} % Specifies where to look for included images (trailing slash required)
\RequirePackage{xcolor}
\RequirePackage{booktabs}
\RequirePackage{lastpage} % Number of pages in the document
\RequirePackage[english]{babel} % Specify a different language here - english by default

\RequirePackage{flushend}

\AtEndOfClass{\RequirePackage{microtype}}

\flushbottom % Makes all text pages the same height

%----------------------------------------------------------------------------------------
%	FONTS
%----------------------------------------------------------------------------------------

%\RequirePackage[utf8]{inputenc}
%% Changed DA 20230421
%%\RequirePackage{times} % Loads the Times Roman Fonts
\RequirePackage{lmodern}
\RequirePackage{mathptmx} % Loads the Times Roman Math Fonts

%% Added DA 20230421
\renewcommand{\familydefault}{\sfdefault}

\definecolor{color1}{RGB}{1,66,122} % Color of the article title and sections
\definecolor{color2}{RGB}{0,120,120} % Color of the boxes behind the abstract and headings

%----------------------------------------------------------------------------------------
%	MARGINS
%----------------------------------------------------------------------------------------

\RequirePackage[
	left=2cm,
	right=2cm,
	top=2cm,%.5cm,
	bottom=2cm,
	headheight=11pt,
        %paperheight=28cm,
        %paperwidth=21cm,
	a4paper,
        %landscape
]{geometry}

%----------------------------------------------------------------------------------------
%	FIGURE AND TABLE CAPTIONS
%----------------------------------------------------------------------------------------

\RequirePackage[
	labelfont={bf,sf,small},
	labelsep=period,
	justification=raggedright,
]{caption}

\setlength{\abovecaptionskip}{3pt}
\setlength{\belowcaptionskip}{0pt}

%----------------------------------------------------------------------------------------
%	PAGE HEADER
%----------------------------------------------------------------------------------------

\RequirePackage{fancyhdr} % Needed to define custom headers/footers
\pagestyle{fancy} % Enables the custom headers/footers

\renewcommand{\headrulewidth}{0pt} % No header rule
\renewcommand{\footrulewidth}{0pt} % No footer rule


\fancyhf{}% clear all header and footer fields
\fancyhead[RO]{\small\sffamily\thepage}
\fancyhead[LE]{\small\sffamily\thepage{} -- \@AuthorsRunning}

%----------------------------------------------------------------------------------------
%	SECTION SETUP
%----------------------------------------------------------------------------------------
%% Changed DA 20230421

\RequirePackage[explicit]{titlesec}

\titleformat{\section}
	{\color{color1}\large\sffamily\bfseries}
%	{\thesection.}
%	{0.5em}
	{}
	{0em}
	{#1}
	[]

%\titleformat{\section}
%	{\color{color1}\large\sffamily\bfseries}
%	{}
%	{0em}
%	{\colorbox{color2!10}{\parbox{\dimexpr\linewidth-2\fboxsep\relax}{\centering\thesection.\space#1}}}
%	[]

\titleformat{name=\section,numberless}
	{\color{color1}\large\sffamily\bfseries}
	{}
	{0em}
	{#1}
	[]

%\titleformat{name=\section,numberless}
%	{\color{color1}\large\sffamily\bfseries}
%	{}
%	{0em}
%	{\colorbox{color2!10}{\parbox{\dimexpr\linewidth-2\fboxsep\relax}{\centering#1}}}
%	[]

\titleformat{\subsection}
	{\color{color1}\sffamily\bfseries}
%	{\thesubsection}
%	{0.5em}
	{}
	{0em}
	{#1}
	[]

\titleformat{\subsubsection}
	{\sffamily\small\bfseries}
%	{\thesubsubsection}
%	{0.5em}
	{}
	{0em}
	{#1}
	[]

\titleformat{\paragraph}[runin]
	{\sffamily\small\bfseries}
	{}
	{0em}
	{#1} 

\titlespacing*{\section}{0pc}{3ex \@plus4pt \@minus3pt}{5pt}
\titlespacing*{\subsection}{0pc}{2.5ex \@plus3pt \@minus2pt}{0pt}
\titlespacing*{\subsubsection}{0pc}{2ex \@plus2.5pt \@minus1.5pt}{0pt}
\titlespacing*{\paragraph}{0pc}{1.5ex \@plus2pt \@minus1pt}{10pt}

%% DA 20230421 - Moved here from the sample
\setlength{\columnsep}{0.55cm} % Distance between the two columns of text
\setlength{\fboxrule}{0.75pt} % Width of the border around the abstract

\newcommand{\keywordname}{Keywords} % Defines the keywords heading name
\newcommand{\coorespondingauthorname}{*\textbf{Corresponding author}: }
%----------------------------------------------------------------------------------------
%	TABLE OF CONTENTS SETUP
%----------------------------------------------------------------------------------------

\newlength{\tocsep} 
\setlength\tocsep{1.5pc} % Sets the indentation of the sections in the table of contents
\setcounter{tocdepth}{3} % Three levels in the table of contents section: sections, subsections and subsubsections

\usepackage{titletoc}
\contentsmargin{0cm}

\titlecontents{section}[\tocsep]
	{\addvspace{4pt}\small\bfseries\sffamily}
	{\contentslabel[\thecontentslabel]{\tocsep}}
	{}
	{\hfill\thecontentspage}
	[]

\titlecontents{subsection}[\tocsep]
	{\addvspace{2pt}\sffamily}
	{\contentslabel[\thecontentslabel]{\tocsep}}
	{}
	{\ \titlerule*[.5pc]{.}\ \thecontentspage}
	[]

\titlecontents*{subsubsection}[\tocsep]
	{\footnotesize\sffamily}
	{}
	{}
	{}
	[\ \textbullet\ ]

%----------------------------------------------------------------------------------------
%	MULTIPLE AUTHOR SET
%----------------------------------------------------------------------------------------

\newcount\@authcnt
\newcount\@tmpcnt\@tmpcnt\z@

\def\@affiliation{%
	\ifnum\@tmpcnt<\@authcnt
		 \global\advance\@tmpcnt1
		\raggedright \csname @auth\romannumeral\the\@tmpcnt\endcsname\hfill\\%
		 \let\next\@affiliation \vskip1pt
	\else
		\let\next\relax
	\fi
	\next%
}

\newcommand{\affiliation}[1]{%
	\global\advance\@authcnt1
	\expandafter\gdef\csname @auth\romannumeral\the\@authcnt\endcsname
	{#1}
}

%----------------------------------------------------------------------------------------
%	LISTS
%----------------------------------------------------------------------------------------

\RequirePackage{enumitem}
%\setlist{nolistsep} % Uncomment to remove spacing before lists (enumerate, itemize)

%----------------------------------------------------------------------------------------
%	ABSTRACT AND AUTHOR FRAME
%----------------------------------------------------------------------------------------

\newcommand{\PaperTitle}[1]{\def\@PaperTitle{#1}}
\newcommand{\Authors}[1]{\def\@Authors{#1}}
\newcommand{\Abstract}[1]{\def\@Abstract{#1}}
\newcommand{\Keywords}[1]{\def\@Keywords{#1}}
\newcommand{\AuthorsRunning}[1]{\def\@AuthorsRunning{#1}}
\newcommand{\CorrespondingAuthorEmail}[1]{\def\@CorrespondingAuthorEmail{#1}}
\newcommand{\PaperType}[1]{\def\@PaperType{#1}}
\newcommand{\JournalInfo}[1]{\def\@JournalInfo{#1}}
\newcommand{\Archive}[1]{\def\@Archive{#1}}

%\newcommand{\OralContrib}[1]{\def\@OralContrib{#1}}
\newcommand{\OralContrib}{Oral contribution}
\newcommand{\PolicySession}{Policy Session}
\newcommand{\EducationalSession}{Educational Session}
\newcommand{\InnovationArea}{Innovation Area}

%\JournalInfo{AAATE 2023 Conference, Paris} % Journal information
%\Archive{\@PaperType{}~(extended abstract)} % Additional notes (e.g. copyright, DOI, review/research article)

% ---------------------------------------------------------------------
\renewcommand{\@maketitle}{%
    \twocolumn[{%
	%\vskip-36pt%
	%{\raggedleft\small\sffamily\bfseries\@JournalInfo\\\@Archive\par}%
	\vskip8pt%
	{\raggedright\color{color1}\sffamily\bfseries\fontsize{20}{25}\selectfont \@PaperTitle\par}%
	\vskip10pt%
	{\raggedright\color{color1}\sffamily\fontsize{12}{16}\selectfont \@Authors\par}%
	\vskip4pt%
	\begingroup%
	   \raggedright\sffamily\small%
	   \footnotesize\@affiliation\par%
          \footnotesize\coorespondingauthorname\@CorrespondingAuthorEmail\par%
        \endgroup%%
	\vskip12pt%
	\fcolorbox{color1}{white}{\colorbox{color2!10}{%
%            \parbox{\textwidth-2\fboxsep-2\fboxrule}{\centering%
%		      \parbox{\textwidth-4\fboxsep-2\fboxrule}{%
            \parbox{\linewidth-2\fboxsep-2\fboxrule}{\centering%
		      \parbox{\linewidth-4\fboxsep-2\fboxrule}{%
		      \ifx\@Keywords\@empty%
		          \sffamily\textbf{\abstractname}\\\@Abstract%
		      \else%
                    \ifx\@Abstract\@empty%
                        \textbf{\keywordname}\\\@Keywords%
                    \else%
                        \sffamily\textbf{\abstractname}\\\@Abstract\\[4pt]%
                        \textbf{\keywordname}\\\@Keywords%
                    \fi%
                }%
            }%
        }}
        \vskip20pt%
    }]%
%\vfill 
    \copyrightstatement
}

%----------------------------------------------------------------------------------------
%	REFERENCES
%----------------------------------------------------------------------------------------

\renewcommand{\@biblabel}[1]{\bfseries\color{color1}\textsuperscript{[#1]}} % Styling of the reference numbers in the bibliography
%\setlength{\bibitemsep}{0cm}

\let\oldbibliography\thebibliography

\renewcommand{\thebibliography}[1]{%
	\addcontentsline{toc}{section}{\refname}%
	\oldbibliography{#1}%
	\setlength\itemsep{0pt}%
}

\newcommand{\ReferenceList}{
  \phantomsection 
  \bibliographystyle{vancouver}
}

%----------------------------------------------------------------------------------------
%	HYPERLINKS
%----------------------------------------------------------------------------------------

\usepackage{hyperref} % Required for hyperlinks
\hypersetup{
	hidelinks,
	colorlinks,
	breaklinks=true,
	urlcolor=color2,
	citecolor=color1,
	linkcolor=color1,
	bookmarksopen=false,
	pdftitle={Title},
	pdfauthor={Author},
}

\Abstract{}

%define \copyrightstatement command for easier use
\newcommand{\copyrightstatement}{
\begin{figure}[!b]
\parbox{\linewidth}{%
\noindent\rule{\linewidth}{0.4pt}
\footnotesize{}Copyright: \copyright~AAATE and \@AuthorsRunning~2023. 
This is an open-access extended abstract of a contribution
(\@PaperType{}) given at the \textbf{AAATE 2023 Conference} in
Paris.\\
It is distributed under the terms of the Creative Commons
Attribution-NonCommercial-NoDerivatives 4.0 International License
(\href{https://creativecommons.org/licenses/by-nc-nd/4.0/}{CC BY-NC-ND
  4.0}), which permits copy and reproduction of the material in any
medium or format, provided the original author and source are
credited.}
\end{figure}%
}

\pagestyle{empty}
